@@ -12,8 +12,19 @@ use Plack::Util;
 use Plack::Middleware::ContentLength;
 use POSIX qw(EINTR);
 use Socket qw(IPPROTO_TCP TCP_NODELAY);
-use Time::HiRes qw(alarm time);
+
 use Try::Tiny;
+use Time::HiRes qw(time);
+
+my $alarm_interval;
+BEGIN {
+    if ($^O eq 'MSWin32') {
+        $alarm_interval = 1;
+    } else {
+        Time::HiRes->import('alarm');
+        $alarm_interval = 0.1;
+    }
+}
 
 use constant MAX_REQUEST_SIZE => 131072;
 use constant MSWin32          => $^O eq 'MSWin32';
@@ -211,7 +222,7 @@ sub do_timeout {
         # got EINTR
         my $left = $wait_until - time;
         last if $left <= 0;
-        alarm($left + 0.1);
+        alarm($left + $alarm_interval);
     }
     alarm(0);
     $ret;
